function [averagetemp,f,x,y] = AFMtemp_radiation(Ls,Lend,Power,Lb,n,h,emissivity,Ts)

La=15e-6;  %anchor length
kmat = 125; %Thermal conductivity of PloySi in W/mK
kso =1.4;  %%Thermal conductivity of SiO2 in W/mK
E= 167.5e9;%Young's modulus Pa
alphat = 2.6e-6;%Coefficient of thermal expansion
rho = 2300; %Density

%Variables That can be changed
%{
Ls = 6e-6; %Spot diameter
Lend = 2e-6; %Spot location from tip
Power = 100; %Laser Power
Lb = 24e-6; %Length of Beam
n=1400; %Number of Segments
h=0.34e-6; %Beam thickness
emissivity = 0.5;%Emissivity
Ts=300; %Surrounding temperature
%}

x1=linspace(0,La,n);
x2=linspace(La,La+Lb-Ls-Lend,n);
x3=linspace(La+Lb-Ls-Lend,La+Lb-Lend,n);
x4=linspace(La+Lb-Lend,La+Lb,n);

xinit=horzcat(x1,x2,x3,x4);
solinit = bvpinit(xinit,[1; 0]);
options =[];

sol = bvp4c(@firstode,@bc,solinit,options,Power,Lb,Ls,h,emissivity,Ts,kmat,kso);
x = xinit;
T = deval(sol,x);
y = T(1,:);

%Plot
%{
plot(x,T(1,:),'m','Linewidth',2);
xlabel('Along the Length of the Beam (m)');
ylabel('Temperature (K)');
title('Temperature Distribution of an AFM cantilever');
%}

%Finding average temperature
[m,n1]=size(xinit);
averagetemp = sum(y,2)/n1;

%Frequecny
f= 0.161*(h/(Lb^2))*sqrt((E-15.8e6*averagetemp*exp(-averagetemp/Ts))*(1+alphat*(averagetemp-Ts))/rho);


