function ds = firstode(x,T,region,Power,Lb,Ls,h,emissivity,Ts,kmat,kso)
ds = zeros(size(T));
%%BEAM DIMENSIONS
L=Lb; %Length of beam (m)
w=Ls; %width of beam (m)
thickness=h; %Thickness (m)
%% RADIATION PROPERTIES
stefan=5.67e-8; %Stefan boltzmann constant
e = emissivity; %Emissivity
T_surr = Ts; %Surrounding temperature (K)
%% THERMAL CONDUCTIVITIES & PROPERTIES
kp=kmat; %polysilicon W/m degree Kelvin
ko=kso;  %SiO2 W/m degree Kelvin
%% Laser Properties
power = Power; %Laser power in Watts
alpha = 1; % absorptivity of polysilicon for lambda=658nm
%% AREAS
Ac = w*thickness; %cross sectional area of the beam
As = 2*L*w+2*L*thickness; % surface area of the beam subjected to radiation
%% REDUCING TO FIRST ODE
%Anchor d^2T/dx^2 = 0
%part 2 of beam d^2T/dx^2=[stefan*emissivity*As(T^4-T_surr^4)]/kp*Ac
%part 3 of beam d^2T/dx^2=[stefan*emissivity*As(T^4-T_surr^4) -
%alpha*Power]/kp*Ac
%part 4 of beam d^2T/dx^2=[stefan*emissivity*As(T^4-T_surr^4)]/kp*Ac
C1= (stefan*e*As)/(kp*Ac);
ds(1) = T(2);

switch region
    case 1 %x [0,La]
        ds(2) = 0;
    case 2 %x [La,La+Ls]
        ds(2) = C1*(T(1)^4-T_surr^4);
    case 3 %x [La+Ls,La+Ls+d]
        ds(2) = C1*(T(1)^4-T_surr^4)-(alpha*power)/(kp*Ac);
    case 4 %x [La+Ls+d,La+Ls+d+Lend]
        ds(2) = C1*(T(1)^4-T_surr^4);
end

end
